
from io import open
from setuptools import setup

version = '1.0.0'



setup(
    name='search_add',
    version=version,

    author='Al3x2345',
    author_email='starkovalex2345@gmail.com',




    license='Apache License, Version 2.0, see LICENSE file',

    packages=['search_add'],

    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: Implementation :: CPython',
    ]
)
